==> typolight-2.6.1.tar.gz: typolight-2.6.1/system/modules/backend/languages/de/languages.php <==
<?php if (!defined('TL_ROOT')) die('You can not access this file directly!');

/**
 * TYPOlight webCMS
 * Copyright (C) 2005 Leo Feyer
 *
 * This program is free software: you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation, either
 * version 2.1 of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public
 * License along with this program. If not, please visit the Free
 * Software Foundation website at http://www.gnu.org/licenses/.
 *
 * PHP version 5
 * @copyright  Leo Feyer 2005
 * @author     Leo Feyer <leo@typolight.org>
 * @package    Language
 * @license    LGPL
 * @filesource
 */


/**
 * Languages
 */
$GLOBALS['TL_LANG']['LNG']['af'] = 'Afrikaans';
$GLOBALS['TL_LANG']['LNG']['ar'] = 'Arabisch';
$GLOBALS['TL_LANG']['LNG']['bg'] = 'Bulgarisch';
$GLOBALS['TL_LANG']['LNG']['ca'] = 'Katalanisch';
$GLOBALS['TL_LANG']['LNG']['cs'] = 'Tschechisch';
$GLOBALS['TL_LANG']['LNG']['da'] = 'Dänisch';
$GLOBALS['TL_LANG']['LNG']['de'] = 'Deutsch'; 
$GLOBALS['TL_LANG']['LNG']['el'] = 'Griechisch';
$GLOBALS['TL_LANG']['LNG']['en'] = 'Englisch';
$GLOBALS['TL_LANG']['LNG']['es'] = 'Spanisch';
$GLOBALS['TL_LANG']['LNG']['et'] = 'Estnisch';
$GLOBALS['TL_LANG']['LNG']['fa'] = 'Persisch';
$GLOBALS['TL_LANG']['LNG']['fi'] = 'Finnisch';
$GLOBALS['TL_LANG']['LNG']['fo'] = 'Färöisch';
$GLOBALS['TL_LANG']['LNG']['fr'] = 'Französisch';
$GLOBALS['TL_LANG']['LNG']['he'] = 'Hebräisch';
$GLOBALS['TL_LANG']['LNG']['hr'] = 'Kroatisch';
$GLOBALS['TL_LANG']['LNG']['hu'] = 'Ungarisch';
$GLOBALS['TL_LANG']['LNG']['id'] = 'Indonesisch';
$GLOBALS['TL_LANG']['LNG']['is'] = 'Isländisch';
$GLOBALS['TL_LANG']['LNG']['it'] = 'Italienisch';
$GLOBALS['TL_LANG']['LNG']['iw'] = 'Hebräisch';
$GLOBALS['TL_LANG']['LNG']['ja'] = 'Japanisch';
$GLOBALS['TL_LANG']['LNG']['ko'] = 'Koreanisch';
$GLOBALS['TL_LANG']['LNG']['lt'] = 'Litauisch';
$GLOBALS['TL_LANG']['LNG']['lv'] = 'Lettisch';
$GLOBALS['TL_LANG']['LNG']['nl'] = 'Niederländisch';
$GLOBALS['TL_LANG']['LNG']['no'] = 'Norwegisch';
$GLOBALS['TL_LANG']['LNG']['pl'] = 'Polnisch';
$GLOBALS['TL_LANG']['LNG']['pt'] = 'Portugiesisch';
$GLOBALS['TL_LANG']['LNG']['ro'] = 'Rumänisch';
$GLOBALS['TL_LANG']['LNG']['ru'] = 'Russisch';
$GLOBALS['TL_LANG']['LNG']['sk'] = 'Slowakisch';
$GLOBALS['TL_LANG']['LNG']['sl'] = 'Slowenisch';
$GLOBALS['TL_LANG']['LNG']['sq'] = 'Albanisch';
$GLOBALS['TL_LANG']['LNG']['sr'] = 'Serbisch';
$GLOBALS['TL_LANG']['LNG']['sv'] = 'Schwedisch';
$GLOBALS['TL_LANG']['LNG']['tr'] = 'Türkisch';
$GLOBALS['TL_LANG']['LNG']['uk'] = 'Ukrainisch';
$GLOBALS['TL_LANG']['LNG']['vi'] = 'Vietnamesisch';
$GLOBALS['TL_LANG']['LNG']['zh'] = 'Chinesisch';

?>

==> typolight-2.6.2.tar.gz: typolight-2.6.2/system/modules/backend/languages/de/languages.php <==
<?php if (!defined('TL_ROOT')) die('You can not access this file directly!');

/**
 * TYPOlight webCMS
 * Copyright (C) 2005 Leo Feyer
 *
 * This program is free software: you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation, either
 * version 2.1 of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public
 * License along with this program. If not, please visit the Free
 * Software Foundation website at http://www.gnu.org/licenses/.
 *
 * PHP version 5
 * @copyright  Leo Feyer 2005
 * @author     Leo Feyer <leo@typolight.org>
 * @package    Language
 * @license    LGPL
 * @filesource
 */


/**
 * Languages
 */
$GLOBALS['TL_LANG']['LNG']['af'] = 'Afrikaans';
$GLOBALS['TL_LANG']['LNG']['ar'] = 'Arabisch';
$GLOBALS['TL_LANG']['LNG']['bg'] = 'Bulgarisch';
$GLOBALS['TL_LANG']['LNG']['ca'] = 'Katalanisch';
$GLOBALS['TL_LANG']['LNG']['cr'] = 'Cree';
$GLOBALS['TL_LANG']['LNG']['cs'] = 'Tschechisch';
$GLOBALS['TL_LANG']['LNG']['da'] = 'Dänisch';
$GLOBALS['TL_LANG']['LNG']['de'] = 'Deutsch'; 
$GLOBALS['TL_LANG']['LNG']['el'] = 'Griechisch';
$GLOBALS['TL_LANG']['LNG']['en'] = 'Englisch';
$GLOBALS['TL_LANG']['LNG']['es'] = 'Spanisch';
$GLOBALS['TL_LANG']['LNG']['et'] = 'Estnisch';
$GLOBALS['TL_LANG']['LNG']['fa'] = 'Persisch';
$GLOBALS['TL_LANG']['LNG']['fi'] = 'Finnisch';
$GLOBALS['TL_LANG']['LNG']['fo'] = 'Färöisch';
$GLOBALS['TL_LANG']['LNG']['fr'] = 'Französisch';
$GLOBALS['TL_LANG']['LNG']['gl'] = 'Galicisch';
$GLOBALS['TL_LANG']['LNG']['he'] = 'Hebräisch';
$GLOBALS['TL_LANG']['LNG']['hr'] = 'Kroatisch';
$GLOBALS['TL_LANG']['LNG']['hu'] = 'Ungarisch';
$GLOBALS['TL_LANG']['LNG']['id'] = 'Indonesisch';
$GLOBALS['TL_LANG']['LNG']['is'] = 'Isländisch';
$GLOBALS['TL_LANG']['LNG']['it'] = 'Italienisch';
$GLOBALS['TL_LANG']['LNG']['ja'] = 'Japanisch';
$GLOBALS['TL_LANG']['LNG']['ko'] = 'Koreanisch';
$GLOBALS['TL_LANG']['LNG']['lt'] = 'Litauisch';
$GLOBALS['TL_LANG']['LNG']['lv'] = 'Lettisch';
$GLOBALS['TL_LANG']['LNG']['nl'] = 'Niederländisch';
$GLOBALS['TL_LANG']['LNG']['no'] = 'Norwegisch';
$GLOBALS['TL_LANG']['LNG']['pl'] = 'Polnisch';
$GLOBALS['TL_LANG']['LNG']['pt'] = 'Portugiesisch';
$GLOBALS['TL_LANG']['LNG']['ro'] = 'Rumänisch';
$GLOBALS['TL_LANG']['LNG']['ru'] = 'Russisch';
$GLOBALS['TL_LANG']['LNG']['sk'] = 'Slowakisch';
$GLOBALS['TL_LANG']['LNG']['sl'] = 'Slowenisch';
$GLOBALS['TL_LANG']['LNG']['so'] = 'Somali';
$GLOBALS['TL_LANG']['LNG']['sq'] = 'Albanisch';
$GLOBALS['TL_LANG']['LNG']['sr'] = 'Serbisch';
$GLOBALS['TL_LANG']['LNG']['sv'] = 'Schwedisch';
$GLOBALS['TL_LANG']['LNG']['th'] = 'Thai';
$GLOBALS['TL_LANG']['LNG']['tr'] = 'Türkisch';
$GLOBALS['TL_LANG']['LNG']['uk'] = 'Ukrainisch';
$GLOBALS['TL_LANG']['LNG']['vi'] = 'Vietnamesisch';
$GLOBALS['TL_LANG']['LNG']['zh'] = 'Chinesisch';

?>
